@@ -4,7 +4,6 @@ import sys
 
 
 def mesh(parser):
-
     # mesh
     parser.add_argument('mesh')
 
@@ -33,7 +32,7 @@ def generate_only(parser):
         '--generate-only', "--no-run", "--skip-run",
         action="store_true",
         help=msg
-        )
+    )
 
 
 def log_level(parser):
@@ -56,16 +55,11 @@ def log_level(parser):
 
 
 def server(parser):
-
-    # flag some options as required when a resource manager is enabled
-    _required = "--use-torque" in sys.argv
-    _required = _required | ("--use-pbs" in sys.argv)
-    _required = _required | ("--use-slurm" in sys.argv)
-
     # add server options
     parser.add_argument('--hostname')
     parser.add_argument('--port', type=int)
-    parser.add_argument("--wdir", required=_required)
+    parser.add_argument(
+        "--wdir", required=True if '--hostname' in sys.argv else False)
     parser.add_argument("--keep-wdir", action="store_true")
     parser.add_argument(
         "--binaries-path", "--binaries-prefix",
@@ -86,15 +80,32 @@ def server(parser):
     manager.add_argument('--use-pbs', action="store_true")
     manager.add_argument('--use-slurm', action="store_true")
 
+    # flag some options as required when a resource manager is enabled
+    _required = "--use-torque" in sys.argv
+    _required = _required | ("--use-pbs" in sys.argv)
+    _required = _required | ("--use-slurm" in sys.argv)
+
     # resource manager specific options
     parser.add_argument('--account', required=_required)
-    parser.add_argument('--walltime', required=_required)
+    parser.add_argument('--slurm-ntasks', required=_required, type=int)
+    parser.add_argument('--partition', required=_required)
+    parser.add_argument('--walltime', required=_required, type=float)
+    parser.add_argument('--slurm-filename')
+    parser.add_argument('--slurm-rundir')
+    parser.add_argument('--run-name')
+    parser.add_argument('--mail-type')
+    parser.add_argument('--mail-user')
+    parser.add_argument('--log-filename')
+    parser.add_argument('--path-prefix')
+    parser.add_argument('--slurm-nodes')
+    parser.add_argument('--slurm-launcher', default='srun')
+    parser.add_argument('--extra-commands', action='append')
     parser.add_argument(
         '--module',
         default=list(),
         action='append',
         dest='modules'
-        )
+    )
 
 
 def tidal_constituents(parser):
@@ -115,7 +126,7 @@ def tidal_constituents(parser):
         dest='constituents',
         default=[],
         help=msg
-        )
+    )
 
 
 def timestep(parser):
@@ -125,10 +136,10 @@ def timestep(parser):
 def gwce_solution_scheme(parser):
     parser.add_argument(
         "--gwce-solution-scheme",
-        choices=['semi-implicit', 'explicit'],
-        # default='explicit'
+        choices=['semi-implicit', 'explicit', 'semi-implicit-legacy'],
+        # default='explicit',
         default='semi-implicit'
-        )
+    )
 
 
 def boundaries_generation(parser):
@@ -139,13 +150,13 @@ def boundaries_generation(parser):
         default=20,
         type=int,
         choices=[0, 10, 20]
-        )
+    )
     parser.add_argument(
         "--island-ibtype",
         default=21,
         type=int,
         choices=[1, 11, 21]
-        )
+    )
 
 
 def best_track(parser):
@@ -213,7 +224,7 @@ def nodal_attributes(parser):
         action='append',
         dest='coldstart_attributes',
         help=msg
-        )
+    )
 
     # hotstart attributes
     msg = "Use nodal attribute that exists in fort.13 during hotstart "
@@ -241,7 +252,7 @@ def surface_output(physical_var, parser, spinup=False):
         short_name,
         type=float,
         help=msg
-        )
+    )
 
     # # surface output start
     # msg = f"Set {physical_var} surface output starting time in days (after "
@@ -275,7 +286,7 @@ def surface_output(physical_var, parser, spinup=False):
             action='store_true',
             default=False,
             help=msg
-            )
+        )
 
 
 def stations_output(physical_var, parser, spinup=False):
@@ -328,7 +339,7 @@ def stations_output(physical_var, parser, spinup=False):
             action='store_true',
             default=False,
             help=msg
-            )
+        )
 
 
 def spinup_outputs(parser):
@@ -343,7 +354,6 @@ def spinup_outputs(parser):
 
 
 def outputs(parser):
-
     # add surface output requests
     surface_output('elevation', parser)
     surface_output('velocity', parser)
@@ -357,7 +367,7 @@ def outputs(parser):
     parser.add_argument(
         "--stations-file",
         help=msg
-        )
+    )
 
     # stations output requests
     stations_output('elevation', parser)
