@@ -3,7 +3,7 @@ from datetime import timedelta
 from functools import lru_cache
 import pathlib
 
-from adcircpy import AdcircMesh, AdcircRun, Tides  # BestTrackForcing, ServerConfig, SlurmConfig,
+from adcircpy import AdcircMesh, AdcircRun, Tides, server
 
 
 class AdcircCommand:
@@ -14,17 +14,17 @@ class AdcircCommand:
     def run(self):
 
         # write and exit if generate only
-        if self.args.generate_only:
+        if self._args.generate_only:
             self.driver.write(
-                self.args.output_directory,
-                overwrite=self.args.overwrite
-                )
+                self._args.output_directory,
+                overwrite=self._args.overwrite
+            )
             return
 
         outputs = self.driver.run(
             outdir=self.output_directory,
-            nproc=self.args.nproc,
-            overwrite=self.args.overwrite,
+            nproc=self._args.nproc,
+            overwrite=self._args.overwrite,
             server_config=self.server_config,
         )
         self._output_collection = outputs
@@ -37,11 +37,12 @@ class AdcircCommand:
             self.start_date,
             self.end_date,
             self.spinup_time,
+            server_config=self.server_config
         )
         self._enable_outputs(driver)
-        if self.args.timestep:
-            driver.timestep = self.args.timestep
-        driver.gwce_solution_scheme = self.args.gwce_solution_scheme
+        if self._args.timestep:
+            driver.timestep = self._args.timestep
+        driver.gwce_solution_scheme = self._args.gwce_solution_scheme
         return driver
 
     @property
@@ -57,13 +58,9 @@ class AdcircCommand:
         try:
             return self.__spinup_time
         except AttributeError:
-            self.__spinup_time = timedelta(days=self.args.spinup_days)
+            self.__spinup_time = timedelta(days=self._args.spinup_days)
             return self.__spinup_time
 
-    @property
-    def args(self):
-        return self._args
-
     @property
     def mesh(self):
         return self._mesh
@@ -92,8 +89,8 @@ class AdcircCommand:
 
     @property
     def output_directory(self):
-        if self.args.output_directory is not None:
-            return pathlib.Path(self.args.output_directory).absolute()
+        if self._args.output_directory is not None:
+            return pathlib.Path(self._args.output_directory).absolute()
 
     @property
     def constituents(self):
@@ -103,52 +100,66 @@ class AdcircCommand:
             # might be better to get these from Tides()
             _major = ('Q1', 'O1', 'P1', 'K1', 'N2', 'M2', 'S2', 'K2')
             _all = (*_major, 'Mm', 'Mf', 'M4', 'MN4', 'MS4', '2N2', 'S1')
-            if ('all' in self.args.constituents
-                    and len(self.args.constituents) > 1):
+            if ('all' in self._args.constituents
+                    and len(self._args.constituents) > 1):
                 msg = 'When using all, must only pass one'
                 raise IOError(msg)
 
-            elif ('major' in self.args.constituents
-                  and len(self.args.constituents) > 1):
+            elif ('major' in self._args.constituents
+                  and len(self._args.constituents) > 1):
                 msg = 'When using major, must only pass one'
                 raise IOError(msg)
-            if 'all' in self.args.constituents:
+            if 'all' in self._args.constituents:
                 constituents = _all
-            elif 'major' in self.args.constituents:
+            elif 'major' in self._args.constituents:
                 constituents = _major
             else:
-                constituents = self.args.constituents
+                constituents = self._args.constituents
             self.__constituents = constituents
             return self.__constituents
 
     @property
+    @lru_cache(maxsize=None)
     def server_config(self):
-        if self.args.hostname:
-            if (not self.args.use_slurm or
-                    not self.args.use_torque or
-                    not self.args.use_pbs):
-                server_config = ServerConfig(
-                    hostname=self.args.hostname,
-                    nprocs=self.args.nproc,
-                    wdir=self.args.wdir,
-                    binaries_prefix=self.args.binaries_prefix,
-                    source_script=self.args.source_script,
-                    additional_mpi_options=self.args.additional_mpi_options,
+        if self._args.hostname:
+            if (not self._args.use_slurm or
+                    not self._args.use_torque or
+                    not self._args.use_pbs):
+                return server.ServerConfig(
+                    hostname=self._args.hostname,
+                    nprocs=self._args.nproc,
+                    wdir=self._args.wdir,
+                    binaries_prefix=self._args.binaries_prefix,
+                    source_script=self._args.source_script,
+                    additional_mpi_options=self._args.additional_mpi_options,
                 )
 
-            elif self.args.use_slurm:
-                raise NotImplementedError
-                server_config = SlurmConfig(
-                )
+        if self._args.use_slurm:
+            kwargs = {
+                "account": self._args.account,
+                "ntasks": self._args.slurm_ntasks,
+                "partition": self._args.partition,
+                "walltime": timedelta(hours=self._args.walltime),
+                "mail_type": self._args.mail_type,
+                "mail_user": self._args.mail_user,
+                "log_filename": self._args.log_filename,
+                "modules": self._args.modules,
+                "path_prefix": self._args.path_prefix,
+                "extra_commands": self._args.extra_commands,
+                "launcher": self._args.slurm_launcher,
+                "nodes": self._args.slurm_nodes
+            }
+            if self._args.slurm_filename is not None:
+                kwargs.update({"filename": self._args.slurm_ntasks})
+            if self._args.slurm_rundir is not None:
+                kwargs.update({"run_directory": self._args.slurm_rundir})
+            if self._args.run_name is not None:
+                kwargs.update({"run_name": self._args.run_name})
 
-            elif self.args.use_torque or self.args.use_pbs:
-                raise NotImplementedError
+            return server.SlurmConfig(**kwargs)
 
-        else:
-            server_config = None
-
-        self.__server_config = server_config
-        return self.__server_config
+        elif self._args.use_torque or self._args.use_pbs:
+            raise NotImplementedError
 
     def _enable_outputs(self, driver):
         self._enable_output(driver, 'elevation', 'surface')
@@ -158,70 +169,66 @@ class AdcircCommand:
         self._init_output_stations(driver)
 
     def _enable_output(self, driver, name, _type):
-        fs = getattr(self.args, f"{name}_{_type}_sampling_rate")
+        fs = getattr(self._args, f"{name}_{_type}_sampling_rate")
         if fs is not None:
             fs = timedelta(minutes=fs)
-        fss = getattr(self.args, f"{name}_{_type}_sampling_rate_spinup")
+        fss = getattr(self._args, f"{name}_{_type}_sampling_rate_spinup")
         if fss is not None:
             fss = timedelta(minutes=fss)
-        ha = getattr(self.args, f"{name}_{_type}_harmonic_analysis")
-        # has = getattr(self.args, f"{name}_{_type}_harmonic_analysis_spinup")
+        ha = getattr(self._args, f"{name}_{_type}_harmonic_analysis")
+        # has = getattr(self._args, f"{name}_{_type}_harmonic_analysis_spinup")
         getattr(driver, f"set_{name}_{_type}_output")(
             sampling_rate=fs,
             harmonic_analysis=ha,
             spinup=fss,
-            netcdf=self.args.netcdf,
+            netcdf=self._args.netcdf,
         )
 
     def _init_output_stations(self, driver):
-        if self.args.stations_file is not None:
+        if self._args.stations_file is not None:
             driver.import_stations(
-                pathlib.Path(self.args.stations_file).resolve())
+                pathlib.Path(self._args.stations_file).resolve())
             self._enable_output(driver, 'elevation', 'stations')
             self._enable_output(driver, 'velocity', 'stations')
             self._enable_output(driver, 'meteorological', 'stations')
             self._enable_output(driver, 'concentration', 'stations')
 
-    @property
-    def _args(self):
-        return self.__args
-
     @property
     @lru_cache(maxsize=None)
     def _mesh(self):
         mesh = AdcircMesh.open(
-            self.args.mesh,
-            self.args.crs
+            self._args.mesh,
+            self._args.crs
         )
 
-        if self.args.generate_boundaries:
+        if self._args.generate_boundaries:
             mesh.generate_boundaries(
-                threshold=self.args.boundaries_threshold,
-                land_ibtype=self.args.land_ibtype,
-                interior_ibtype=self.args.island_ibtype,
-                )
-
-        # set nodal attributes
-        if self.args.fort13 is not None:
-            mesh.import_nodal_attributes(
-                pathlib.Path(self.args.fort13).resolve()
+                threshold=self._args.boundaries_threshold,
+                land_ibtype=self._args.land_ibtype,
+                interior_ibtype=self._args.island_ibtype,
             )
 
-        if 'all' in self.args.coldstart_attributes:
+        # set nodal attributes
+        if self._args.fort13 is not None:
+            mesh.import_nodal_attributes(
+                pathlib.Path(self._args.fort13).resolve()
+            )
+
+        if 'all' in self._args.coldstart_attributes:
             for attr in mesh.get_nodal_attribute_names():
                 mesh.set_nodal_attribute_coldstart_state(attr, True)
         else:
-            for attr in self.args.coldstart_attributes:
+            for attr in self._args.coldstart_attributes:
                 mesh.set_nodal_attribute_coldstart_state(attr, True)
 
-        if 'all' in self.args.hotstart_attributes:
+        if 'all' in self._args.hotstart_attributes:
             for attr in mesh.get_nodal_attribute_names():
                 mesh.set_nodal_attribute_hotstart_state(attr, True)
         else:
-            for attr in self.args.hotstart_attributes:
+            for attr in self._args.hotstart_attributes:
                 mesh.set_nodal_attribute_hotstart_state(attr, True)
 
-        if self.args.generate_tau0:
+        if self._args.generate_tau0:
             mesh.generate_tau0()
 
         if self.tidal_forcing is not None:
@@ -233,7 +240,3 @@ class AdcircCommand:
         if self.wind_forcing is not None:
             mesh.add_forcing(self.wind_forcing)
         return mesh
-
-    @_args.setter
-    def _args(self, args):
-        self.__args = args
